@@ -60,6 +60,15 @@ check_ibawds_setup <- function() {
 
   cli::cli_alert_info(paste("Operating system:", sw$os))
 
+  # check the ram
+  ram <- memuse::Sys.meminfo()$totalram
+  cli::cli_alert_info("System memory: {ram}")
+  if (as.numeric(ram) < 15 * 2^30) {
+    cli::cli_alert_warning(
+      "The memory might not be sufficient for some tasks in the course."
+    )
+  }
+
   # check the R version: it should be at most 1 year old
   if (Sys.Date() - sw$R$date < 365) {
     cli::cli_alert_success(paste("R is up to date:", sw$R$version))
@@ -211,6 +220,9 @@ get_software_versions <- function() {
 }
 
 
+# return a vector of packages that are required for the course. These are all
+# the dependencies of ibawds plus some additional packages.
+
 get_required_packages <- function() {
 
   system.file("DESCRIPTION", package = "ibawds") %>%
@@ -224,8 +236,12 @@ get_required_packages <- function() {
     stringr::str_trim() %>%
     # remove the entries for R and packages that are not relevant for the students
     setdiff(c("R", "testthat", "usethis", "vdiffr", "covr", "spelling",
-              "withr", "httr2"))
-
+              "withr", "httr2", "nanoparquet")) %>%
+    # add additional relevant packages
+    c("BiocManager", "caret", "clValid", "cowplot", "DT", "GGally",
+      "ggfortify", "ggrepel", "gutenbergr", "hexbin", "HistData", "Lahman",
+      "party", "patchwork", "ranger", "RANN", "reshape2", "styler",
+      "tidytext", "tidyverse", "titanic", "waldo", "writexl")
 }
 
 
